<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/util_msa_consensus/MSAConsensusUtils.cpp" line="118"/>
        <source>Gaps:</source>
        <translation>Пробелы:</translation>
    </message>
    <message>
        <location filename="../src/misc/FindAlgorithm.cpp" line="160"/>
        <location filename="../src/misc/FindAlgorithm.cpp" line="824"/>
        <source>The search pattern is too long.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>RoughTmCalculatorCmdFactory</name>
    <message>
        <location filename="../src/temperature/rough/RoughTmCalculatorCmdFactory.cpp" line="28"/>
        <source>Rough</source>
        <translation>Приблизительный</translation>
    </message>
</context>
<context>
    <name>U2::AlignInAminoFormTask</name>
    <message>
        <location filename="../src/util_msaedit/MsaUtilTasks.cpp" line="94"/>
        <source>Align in amino form</source>
        <translation>Выравнивание в амино форму</translation>
    </message>
    <message>
        <location filename="../src/util_msaedit/MsaUtilTasks.cpp" line="104"/>
        <source>AlignInAminoFormTask: Input alphabet is not nucleic!</source>
        <translation>AlignInAminoFormTask: Входной алфавит не является нуклеотидным!</translation>
    </message>
    <message>
        <location filename="../src/util_msaedit/MsaUtilTasks.cpp" line="105"/>
        <source>AlignInAminoFormTask: Input alignment is empty!</source>
        <translation>AlignInAminoFormTask: Входное выравнивание пустое!</translation>
    </message>
</context>
<context>
    <name>U2::AlignmentAlgorithmsRegistry</name>
    <message>
        <location filename="../src/msa_alignment/SimpleAddingToAlignment.cpp" line="221"/>
        <source>Align sequences to alignment with UGENE…</source>
        <translation>Добавить последовательности к выравниванию с UGENE...</translation>
    </message>
</context>
<context>
    <name>U2::AssemblyConsensusAlgorithmFactoryDefault</name>
    <message>
        <location filename="../src/util_assembly_consensus/AssemblyConsensusAlgorithmDefault.cpp" line="40"/>
        <source>Default</source>
        <translation>Схема по умолчанию</translation>
    </message>
    <message>
        <location filename="../src/util_assembly_consensus/AssemblyConsensusAlgorithmDefault.cpp" line="44"/>
        <source>Returns simply the most frequent base and &apos;N&apos; are no reads intersecting this position</source>
        <translation>Выдает наиболее часто встречающееся основание в столбце ридов или N если нету ридов в данном столбце</translation>
    </message>
</context>
<context>
    <name>U2::AssemblyConsensusAlgorithmFactorySamtools</name>
    <message>
        <location filename="../src/util_assembly_consensus/AssemblyConsensusAlgorithmSamtools.cpp" line="44"/>
        <source>SAMtools</source>
        <translation>SAMtools</translation>
    </message>
    <message>
        <location filename="../src/util_assembly_consensus/AssemblyConsensusAlgorithmSamtools.cpp" line="48"/>
        <source>Uses SAMtools to calculate consensus with regard to quality of reads</source>
        <translation>Использует SAMtools для расчета консенсуса по отношению к качеству ридов</translation>
    </message>
    <message>
        <location filename="../src/util_assembly_consensus/AssemblyConsensusAlgorithmSamtools.cpp" line="69"/>
        <source>Fetching reads from database and converting to SAMtools format</source>
        <translation>Выборка ридов из базы данных и преобразование в формат SAMtools</translation>
    </message>
    <message>
        <location filename="../src/util_assembly_consensus/AssemblyConsensusAlgorithmSamtools.cpp" line="72"/>
        <source>Sorting reads</source>
        <translation>Сортировка ридов</translation>
    </message>
    <message>
        <location filename="../src/util_assembly_consensus/AssemblyConsensusAlgorithmSamtools.cpp" line="75"/>
        <source>Calculating consensus</source>
        <translation>Вычисление консенсуса</translation>
    </message>
</context>
<context>
    <name>U2::BestPositionFindTask</name>
    <message>
        <location filename="../src/msa_alignment/SimpleAddingToAlignment.cpp" line="153"/>
        <source>Best position find task</source>
        <translation>Задача поиска лучшей позиции</translation>
    </message>
</context>
<context>
    <name>U2::CreateSubalignmentTask</name>
    <message>
        <location filename="../src/util_msaedit/CreateSubalignmentTask.cpp" line="58"/>
        <source>Create sub-alignment: %1</source>
        <translation>Создание участка выравнивания: %1</translation>
    </message>
    <message>
        <location filename="../src/util_msaedit/CreateSubalignmentTask.cpp" line="103"/>
        <source>Document is locked: %1</source>
        <translation>Документ заблокирован: %1</translation>
    </message>
</context>
<context>
    <name>U2::DnaAssemblyMultiTask</name>
    <message>
        <location filename="../src/misc/DnaAssemblyMultiTask.cpp" line="80"/>
        <source>The short reads can&apos;t be mapped to the reference sequence!</source>
        <translation>Короткие риды не могут быть отражены в референсной последовательности!</translation>
    </message>
</context>
<context>
    <name>U2::DnaAssemblyToReferenceTask</name>
    <message>
        <location filename="../src/registry/DnaAssemblyTask.cpp" line="37"/>
        <source>Align short reads</source>
        <translation>Выравнивание коротких ридов</translation>
    </message>
</context>
<context>
    <name>U2::FindAlgorithmTask</name>
    <message>
        <location filename="../src/misc/FindAlgorithmTask.cpp" line="44"/>
        <source>Find in sequence task</source>
        <translation>Поиск Смита-Ватермана</translation>
    </message>
</context>
<context>
    <name>U2::GenomeAssemblyMultiTask</name>
    <message>
        <location filename="../src/misc/GenomeAssemblyMultiTask.cpp" line="80"/>
        <source>Assembly cannot be performed.</source>
        <translation>Сборка не может быть выполнена.</translation>
    </message>
    <message>
        <location filename="../src/misc/GenomeAssemblyMultiTask.cpp" line="98"/>
        <source>Assembly task finished with error: %1</source>
        <translation>Сборка завершилась с ошибкой: %1</translation>
    </message>
    <message>
        <location filename="../src/misc/GenomeAssemblyMultiTask.cpp" line="100"/>
        <source>Assembly task wasn&apos;t set</source>
        <translation>Задача сборки не установлена</translation>
    </message>
    <message>
        <location filename="../src/misc/GenomeAssemblyMultiTask.cpp" line="103"/>
        <source>Assembly was finished successfully</source>
        <translation>Сборка завершилась корректно</translation>
    </message>
    <message>
        <location filename="../src/misc/GenomeAssemblyMultiTask.cpp" line="105"/>
        <source>Assembly failed.</source>
        <translation>Сборка не удалась.</translation>
    </message>
</context>
<context>
    <name>U2::LoadPatternsFileTask</name>
    <message>
        <location filename="../src/misc/FindAlgorithmTask.cpp" line="104"/>
        <source>Load pattern from file</source>
        <translation>Загрузить паттерн из файла</translation>
    </message>
    <message>
        <location filename="../src/misc/FindAlgorithmTask.cpp" line="113"/>
        <source>Detecting format error for file %1</source>
        <translation>Ошибка распознавания формата для файла %1</translation>
    </message>
</context>
<context>
    <name>U2::MSAConsensusAlgorithmFactoryClustal</name>
    <message>
        <location filename="../src/util_msa_consensus/MSAConsensusAlgorithmClustal.cpp" line="30"/>
        <source>Emulates ClustalW program and file format behavior.</source>
        <translation>Эмулирует программу ClustalW и её интерпретацию формата файла.</translation>
    </message>
    <message>
        <location filename="../src/util_msa_consensus/MSAConsensusAlgorithmClustal.cpp" line="34"/>
        <source>ClustalW</source>
        <translation>Схема ClustalW</translation>
    </message>
</context>
<context>
    <name>U2::MSAConsensusAlgorithmFactoryDefault</name>
    <message>
        <location filename="../src/util_msa_consensus/MSAConsensusAlgorithmDefault.cpp" line="35"/>
        <source>Based on JalView algorithm. Returns &apos;+&apos; if there are 2 characters with high frequency. Returns symbol in lower case if the symbol content in a row is lower than the threshold specified.</source>
        <translation>В основе лежит алгоритм JalView. Возвращает &apos;+&apos;ˇ, если имеется 2 символа с высокой частотой. Возвращает символ в нижнем регистре, если символ содержится в ряду меньшее число раз, чем это указано в пороге.</translation>
    </message>
    <message>
        <location filename="../src/util_msa_consensus/MSAConsensusAlgorithmDefault.cpp" line="39"/>
        <source>Default</source>
        <translation>Схема по умолчанию</translation>
    </message>
</context>
<context>
    <name>U2::MSAConsensusAlgorithmFactoryLevitsky</name>
    <message>
        <location filename="../src/util_msa_consensus/MSAConsensusAlgorithmLevitsky.cpp" line="35"/>
        <source>The algorithm proposed by Victor Levitsky to work with DNA alignments.
Collects global alignment frequency for every symbol using extended (15 symbols) DNA alphabet first.
For every column selects the most rare symbol in the whole alignment with percentage in the column greater or equals to the threshold value.</source>
        <translation>Алгоритм представлен Виктором Левицким для работы с выравниваниями ДНК.
В первую очередь алгоритм вычисляет глобальную частоту появления каждого символа в выравнивании с использованием расширенного (15-символьного) алфавита ДНК.
Для каждого столбца выбирается наиболее редко встречаемый символ во всём выравнивании, такой что процентное соотношение его появления в столбце больше либо равно значению порога.</translation>
    </message>
    <message>
        <location filename="../src/util_msa_consensus/MSAConsensusAlgorithmLevitsky.cpp" line="42"/>
        <source>Levitsky</source>
        <translation>Схема Левицкого</translation>
    </message>
</context>
<context>
    <name>U2::MSAConsensusAlgorithmFactoryStrict</name>
    <message>
        <location filename="../src/util_msa_consensus/MSAConsensusAlgorithmStrict.cpp" line="37"/>
        <source>The algorithm returns gap character (&apos;-&apos;) if symbol frequency in a column is lower than threshold specified.</source>
        <translation>Алгоритм возвращает символ пробела (&apos;-&apos;), если частота появления символа в столбце меньше, чем величина, заданная в пороге.</translation>
    </message>
    <message>
        <location filename="../src/util_msa_consensus/MSAConsensusAlgorithmStrict.cpp" line="41"/>
        <source>Strict</source>
        <translation>Строгий</translation>
    </message>
</context>
<context>
    <name>U2::MSADistanceAlgorithm</name>
    <message>
        <location filename="../src/util_msa_distance/MSADistanceAlgorithm.cpp" line="59"/>
        <source>MSA distance algorithm &quot;%1&quot; task</source>
        <translation>Задача вычисления алгоритма дистанций в MSA &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>U2::MSADistanceAlgorithmFactoryHamming</name>
    <message>
        <location filename="../src/util_msa_distance/MSADistanceAlgorithmHamming.cpp" line="33"/>
        <source>Based on Hamming distance between two sequences</source>
        <translation>На основании расстояния Хэмминга между двумя последовательностями</translation>
    </message>
    <message>
        <location filename="../src/util_msa_distance/MSADistanceAlgorithmHamming.cpp" line="37"/>
        <source>Hamming dissimilarity</source>
        <translation>Расхождение Хэмминга</translation>
    </message>
</context>
<context>
    <name>U2::MSADistanceAlgorithmFactoryHammingRevCompl</name>
    <message>
        <location filename="../src/util_msa_distance/MSADistanceAlgorithmHammingRevCompl.cpp" line="38"/>
        <source>Based on Hamming distance between two sequences</source>
        <translation>На основании расстояния Хэмминга между двумя последовательностями</translation>
    </message>
    <message>
        <location filename="../src/util_msa_distance/MSADistanceAlgorithmHammingRevCompl.cpp" line="42"/>
        <source>Hamming reverse-complement</source>
        <translation>Значение Хэмминга для обратно-комплементарной</translation>
    </message>
</context>
<context>
    <name>U2::MSADistanceAlgorithmFactorySimilarity</name>
    <message>
        <location filename="../src/util_msa_distance/MSADistanceAlgorithmSimilarity.cpp" line="33"/>
        <source>Based on similarity distance between two sequences</source>
        <translation>На основании расстояния сходства между двумя последовательностями</translation>
    </message>
    <message>
        <location filename="../src/util_msa_distance/MSADistanceAlgorithmSimilarity.cpp" line="37"/>
        <source>Similarity</source>
        <translation>Простое сходство</translation>
    </message>
</context>
<context>
    <name>U2::MSADistanceAlgorithmHammingRevCompl</name>
    <message>
        <location filename="../src/util_msa_distance/MSADistanceAlgorithmHammingRevCompl.cpp" line="72"/>
        <source>An unexpected error has occurred during running the Hamming reverse-complement algorithm.</source>
        <translation>Произошла ошибка во время запуска обратно-комплементарного алгоритма Хэмминга.</translation>
    </message>
</context>
<context>
    <name>U2::MaConsensusAlgorithmFactorySimpleExtended</name>
    <message>
        <location filename="../src/util_msa_consensus/MaConsensusAlgorithmSimpleExtended.cpp" line="200"/>
        <source>The algorithm selects the best character from the extended DNA alphabet. Only bases with frequences which are greater than a threshold value are taken into account.</source>
        <translation>Алгоритм выбирает лучший символ из расширенного ДНК алфавита. Учитываются только символы с частотой, превышающей пороговое значение.</translation>
    </message>
    <message>
        <location filename="../src/util_msa_consensus/MaConsensusAlgorithmSimpleExtended.cpp" line="205"/>
        <source>Simple extended</source>
        <translation>Простой с расширенным алфавитом</translation>
    </message>
</context>
<context>
    <name>U2::MolecularSurfaceCalcTask</name>
    <message>
        <location filename="../src/molecular_geometry/MolecularSurface.cpp" line="122"/>
        <source>Molecular surface calculation</source>
        <translation>Вычисление молекулярной поверхности</translation>
    </message>
</context>
<context>
    <name>U2::MsaColorSchemeRegistry</name>
    <message>
        <location filename="../src/util_msaedit/color_schemes/MsaColorScheme.cpp" line="564"/>
        <source>No colors</source>
        <translation>Без цвета</translation>
    </message>
    <message>
        <location filename="../src/util_msaedit/color_schemes/MsaColorScheme.cpp" line="572"/>
        <source>UGENE Sanger</source>
        <translatorcomment>UGENE Sanger</translatorcomment>
        <translation>UGENE Sanger</translation>
    </message>
    <message>
        <location filename="../src/util_msaedit/color_schemes/MsaColorScheme.cpp" line="576"/>
        <source>Jalview</source>
        <translation>Jalview</translation>
    </message>
    <message>
        <location filename="../src/util_msaedit/color_schemes/MsaColorScheme.cpp" line="578"/>
        <location filename="../src/util_msaedit/color_schemes/MsaColorScheme.cpp" line="619"/>
        <source>Percentage identity</source>
        <translation>Процентное соотношение</translation>
    </message>
    <message>
        <location filename="../src/util_msaedit/color_schemes/MsaColorScheme.cpp" line="579"/>
        <source>Percentage identity (colored)</source>
        <translation>Процентное соотношение (цветное)</translation>
    </message>
    <message>
        <location filename="../src/util_msaedit/color_schemes/MsaColorScheme.cpp" line="580"/>
        <location filename="../src/util_msaedit/color_schemes/MsaColorScheme.cpp" line="620"/>
        <source>Percentage identity (gray)</source>
        <translation>Процентное соотношение (серый)</translation>
    </message>
    <message>
        <location filename="../src/util_msaedit/color_schemes/MsaColorScheme.cpp" line="582"/>
        <source>Weak similarities</source>
        <translation>Слабая гомология</translation>
    </message>
    <message>
        <location filename="../src/util_msaedit/color_schemes/MsaColorScheme.cpp" line="593"/>
        <source>Zappo</source>
        <translation>Zappo</translation>
    </message>
    <message>
        <location filename="../src/util_msaedit/color_schemes/MsaColorScheme.cpp" line="597"/>
        <source>Tailor</source>
        <translation>Tailor</translation>
    </message>
    <message>
        <location filename="../src/util_msaedit/color_schemes/MsaColorScheme.cpp" line="601"/>
        <source>Hydrophobicity</source>
        <translation>Гидрофобность</translation>
    </message>
    <message>
        <location filename="../src/util_msaedit/color_schemes/MsaColorScheme.cpp" line="605"/>
        <source>Helix propensity</source>
        <translation>Склонность к спиральности</translation>
    </message>
    <message>
        <location filename="../src/util_msaedit/color_schemes/MsaColorScheme.cpp" line="609"/>
        <source>Strand propensity</source>
        <translation>Склонность к линейности</translation>
    </message>
    <message>
        <location filename="../src/util_msaedit/color_schemes/MsaColorScheme.cpp" line="613"/>
        <source>Turn propensity</source>
        <translation>Склонность к сворачиванию</translation>
    </message>
    <message>
        <location filename="../src/util_msaedit/color_schemes/MsaColorScheme.cpp" line="617"/>
        <source>Buried index</source>
        <translation>Индекс</translation>
    </message>
    <message>
        <location filename="../src/util_msaedit/color_schemes/MsaColorScheme.cpp" line="622"/>
        <source>Clustal X</source>
        <translation>Clustal X</translation>
    </message>
</context>
<context>
    <name>U2::MsaHighlightingSchemeRegistry</name>
    <message>
        <location filename="../src/util_msaedit/highlighting_schemes/MsaHighlightingScheme.cpp" line="114"/>
        <source>No highlighting</source>
        <translation>Без подсветки</translation>
    </message>
    <message>
        <location filename="../src/util_msaedit/highlighting_schemes/MsaHighlightingScheme.cpp" line="115"/>
        <source>Agreements</source>
        <translation>Совпадающие нуклеотиды</translation>
    </message>
    <message>
        <location filename="../src/util_msaedit/highlighting_schemes/MsaHighlightingScheme.cpp" line="116"/>
        <source>Disagreements</source>
        <translation>Различающиеся нуклеотиды</translation>
    </message>
    <message>
        <location filename="../src/util_msaedit/highlighting_schemes/MsaHighlightingScheme.cpp" line="117"/>
        <source>Gaps</source>
        <translation>Пробелы</translation>
    </message>
    <message>
        <location filename="../src/util_msaedit/highlighting_schemes/MsaHighlightingScheme.cpp" line="118"/>
        <source>Conservation level</source>
        <translation>Уровень сохранения</translation>
    </message>
    <message>
        <location filename="../src/util_msaedit/highlighting_schemes/MsaHighlightingScheme.cpp" line="119"/>
        <source>Transitions</source>
        <translation>Транзиции</translation>
    </message>
    <message>
        <location filename="../src/util_msaedit/highlighting_schemes/MsaHighlightingScheme.cpp" line="120"/>
        <source>Transversions</source>
        <translation>Трансверсии</translation>
    </message>
</context>
<context>
    <name>U2::ORFFindTask</name>
    <message>
        <location filename="../src/util_orf/ORFAlgorithmTask.cpp" line="31"/>
        <source>ORF find</source>
        <translation>Поиск ORF (рамок считывания)</translation>
    </message>
</context>
<context>
    <name>U2::PWMConversionAlgorithmFactoryBVH</name>
    <message>
        <location filename="../src/util_weight_matrix/PWMConversionAlgorithmBVH.cpp" line="40"/>
        <source>Berg and von Hippel weight function</source>
        <translation>Весовая функция Берга-Гиппеля</translation>
    </message>
</context>
<context>
    <name>U2::PWMConversionAlgorithmFactoryLOD</name>
    <message>
        <location filename="../src/util_weight_matrix/PWMConversionAlgorithmLOD.cpp" line="37"/>
        <source>log-odds</source>
        <translation>log-odds</translation>
    </message>
    <message>
        <location filename="../src/util_weight_matrix/PWMConversionAlgorithmLOD.cpp" line="41"/>
        <source>log-odds weight function</source>
        <translation>Весовая функция log-odds</translation>
    </message>
</context>
<context>
    <name>U2::PWMConversionAlgorithmFactoryMCH</name>
    <message>
        <location filename="../src/util_weight_matrix/PWMConversionAlgorithmMCH.cpp" line="36"/>
        <source>Match</source>
        <translation>Совпадение</translation>
    </message>
    <message>
        <location filename="../src/util_weight_matrix/PWMConversionAlgorithmMCH.cpp" line="40"/>
        <source>Match weight function</source>
        <translation>Весовая функция совпадений</translation>
    </message>
</context>
<context>
    <name>U2::PWMConversionAlgorithmFactoryNLG</name>
    <message>
        <location filename="../src/util_weight_matrix/PWMConversionAlgorithmNLG.cpp" line="36"/>
        <source>NLG</source>
        <translation>NLG</translation>
    </message>
    <message>
        <location filename="../src/util_weight_matrix/PWMConversionAlgorithmNLG.cpp" line="40"/>
        <source>NLG weight function</source>
        <translation>Весовая функция NLG</translation>
    </message>
</context>
<context>
    <name>U2::PairwiseAlignmentTask</name>
    <message>
        <location filename="../src/pairwise_alignment/PairwiseAlignmentTask.cpp" line="46"/>
        <source>Pairwise alignment task</source>
        <translation>Задача парного выравнивания</translation>
    </message>
</context>
<context>
    <name>U2::PhyTreeGeneratorLauncherTask</name>
    <message>
        <location filename="../src/phyltree/PhyTreeGeneratorTask.cpp" line="46"/>
        <source>Calculating Phylogenetic Tree</source>
        <translation>Создание филогенетического дерева</translation>
    </message>
    <message>
        <location filename="../src/phyltree/PhyTreeGeneratorTask.cpp" line="56"/>
        <source>Tree algorithm %1 is not found</source>
        <translation>Алгоритм дерева %1 не найден</translation>
    </message>
    <message>
        <location filename="../src/phyltree/PhyTreeGeneratorTask.cpp" line="81"/>
        <source>Failed to map row name: %1</source>
        <translation>Не удалось сопоставить имя строки: %1</translation>
    </message>
</context>
<context>
    <name>U2::PhyTreeGeneratorTask</name>
    <message>
        <location filename="../src/phyltree/PhyTreeGeneratorTask.cpp" line="33"/>
        <source>Calculating Phylogenetic Tree</source>
        <translation>Создание филогенетического дерева</translation>
    </message>
</context>
<context>
    <name>U2::SecStructPredictTask</name>
    <message>
        <location filename="../src/registry/SecStructPredictTask.cpp" line="27"/>
        <source>Secondary structure predict</source>
        <translation>Предсказание вторичной структуры</translation>
    </message>
</context>
<context>
    <name>U2::SequenceContentFilterTask</name>
    <message>
        <location filename="../src/misc/SequenceContentFilterTask.cpp" line="39"/>
        <source>Sequence content</source>
        <translation>Содержание последовательности</translation>
    </message>
</context>
<context>
    <name>U2::SimpleAddToAlignmentTask</name>
    <message>
        <location filename="../src/msa_alignment/SimpleAddingToAlignment.cpp" line="51"/>
        <source>Align sequences to alignment with UGENE started</source>
        <translation>Выравнивание последовательностей на выравнивание началось</translation>
    </message>
    <message>
        <location filename="../src/msa_alignment/SimpleAddingToAlignment.cpp" line="136"/>
        <source>The following sequence(s) were not aligned as they do not contain meaningful characters: &quot;%1&quot;.</source>
        <translation>Следующие последовательности не были выровнены потому что не содержат символов, имеющих значение: &quot;%1&quot;.</translation>
    </message>
</context>
<context>
    <name>U2::SmithWatermanReportCallbackAnnotImpl</name>
    <message>
        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="64"/>
        <source>Annotation object not found.</source>
        <translation>Не найдена таблица аннотаций.</translation>
    </message>
    <message>
        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="68"/>
        <source>Annotation table is read-only</source>
        <translation>Запрещена запись в таблицу аннотаций</translation>
    </message>
</context>
<context>
    <name>U2::SmithWatermanReportCallbackMAImpl</name>
    <message>
        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="208"/>
        <source>SmithWatermanReportCallback failed to create new MA document</source>
        <translation>SmithWatermanReportCallback не может создать новый MA документ</translation>
    </message>
    <message>
        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="226"/>
        <source>Failed to add a reference subsequence row.</source>
        <translation>Неудачная попытка добавления строки реверенсной подпоследовательности.</translation>
    </message>
    <message>
        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="230"/>
        <source>Failed to add a pattern subsequence row.</source>
        <translation>Неудачная попытка добавления строки подпоследовательности.</translation>
    </message>
    <message>
        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="233"/>
        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="318"/>
        <source>Failed to create an alignment.</source>
        <translation>Неудачная попытка создания выравнивания.</translation>
    </message>
    <message>
        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="261"/>
        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="335"/>
        <source>Smith-Waterman pairwise alignment: no results</source>
        <translation>Парное выравнивание Smith-Waterman: нет результатов</translation>
    </message>
    <message>
        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="268"/>
        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="340"/>
        <source>Sequences aren&apos;t stored in the source msa dbi</source>
        <translation>Последовательности не хранятся в источнике msa dbi</translation>
    </message>
    <message>
        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="284"/>
        <source>SmithWatermanReportCallback failed to create new MA document.</source>
        <translation>SmithWatermanReportCallback не может создать новый MA документ.</translation>
    </message>
    <message>
        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="290"/>
        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="292"/>
        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="349"/>
        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="351"/>
        <source>Failed to get the sequence object.</source>
        <translation>Неудачная попытка получения объекта последовательности.</translation>
    </message>
    <message>
        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="306"/>
        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="308"/>
        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="365"/>
        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="369"/>
        <source>Failed to get the sequence data.</source>
        <translation>Неудачная попытка получения данных последовательности.</translation>
    </message>
    <message>
        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="378"/>
        <source>Failed to get msa from dbi</source>
        <translation>Неудачная попытка получения msa из dbi</translation>
    </message>
    <message>
        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="401"/>
        <location filename="../src/smith_waterman/SmithWatermanReportCallback.cpp" line="403"/>
        <source>Failed to update row gap model</source>
        <translation>Неудачная попытка обновить модель пробелов строк</translation>
    </message>
</context>
<context>
    <name>U2::SplicedAlignmentTask</name>
    <message>
        <location filename="../src/registry/SplicedAlignmentTask.cpp" line="27"/>
        <source>Partial Alignment Task</source>
        <translation>Частичное выравнивание</translation>
    </message>
</context>
<context>
    <name>U2::SubstMatrixRegistry</name>
    <message>
        <location filename="../src/registry/SubstMatrixRegistry.cpp" line="102"/>
        <source>Reading substitution matrix from %1</source>
        <translation>Чтение подстановочной матрицы из %1</translation>
    </message>
    <message>
        <location filename="../src/registry/SubstMatrixRegistry.cpp" line="110"/>
        <source>Error weight matrix file &apos;%1&apos; : %2</source>
        <translation>Ошибка в файле матрицы &quot;%1&quot; : &quot;%2&quot;</translation>
    </message>
    <message>
        <location filename="../src/registry/SubstMatrixRegistry.cpp" line="118"/>
        <source>Error opening file for read: %1</source>
        <translation>Ошибка открытия файла для чтения: &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../src/registry/SubstMatrixRegistry.cpp" line="125"/>
        <source>Error reading file: %1</source>
        <translation>Ошибка чтения файла: &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../src/registry/SubstMatrixRegistry.cpp" line="158"/>
        <location filename="../src/registry/SubstMatrixRegistry.cpp" line="182"/>
        <source>Invalid character token &apos;%1&apos; , line %2</source>
        <translation>Неверный символ: &quot;%1&quot; в строке: &quot;%2&quot;</translation>
    </message>
    <message>
        <location filename="../src/registry/SubstMatrixRegistry.cpp" line="163"/>
        <source>Duplicate character &apos;%1&apos; , line %2</source>
        <translation>Дублированный символ: &quot;%1&quot; в строке &quot;%2&quot;</translation>
    </message>
    <message>
        <location filename="../src/registry/SubstMatrixRegistry.cpp" line="170"/>
        <source>Alphabet is neither nucleic nor protein!</source>
        <translation>Алфавит не является ни нуклеиновым, ни протеиновым!</translation>
    </message>
    <message>
        <location filename="../src/registry/SubstMatrixRegistry.cpp" line="174"/>
        <source>Matrix doesn&apos;t contains score for default alphabet character &apos;%1&apos;</source>
        <translation>Матрица не содержит оценки для символов алфавита по умолчанию &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../src/registry/SubstMatrixRegistry.cpp" line="187"/>
        <source>Invalid character row &apos;%1&apos; , line %2</source>
        <translation>Некорректная последовательность символов &quot;%1&quot; в строке: %2&quot;</translation>
    </message>
    <message>
        <location filename="../src/registry/SubstMatrixRegistry.cpp" line="191"/>
        <source>Duplicate character mapping &apos;%1&apos; , line %2</source>
        <translation>Дублированный символ &quot;%1&quot; в строке &quot;%2&quot;</translation>
    </message>
    <message>
        <location filename="../src/registry/SubstMatrixRegistry.cpp" line="196"/>
        <source>Invalid number of columns &apos;%1&apos; , line %2</source>
        <translation>Неверное число столбцов &quot;%1&quot; в строке %2</translation>
    </message>
    <message>
        <location filename="../src/registry/SubstMatrixRegistry.cpp" line="204"/>
        <source>Can&apos;t parse numeric value &apos;%1&apos;, line %2</source>
        <translation>Невозможно распознать числовое значение &quot;%1&quot; в строке &quot;%2&quot;</translation>
    </message>
    <message>
        <location filename="../src/registry/SubstMatrixRegistry.cpp" line="213"/>
        <source>Unexpected end of file!</source>
        <translation>Неожиданный конец файла!</translation>
    </message>
</context>
<context>
    <name>U2::TranslateMsa2AminoTask</name>
    <message>
        <location filename="../src/util_msaedit/MsaUtilTasks.cpp" line="47"/>
        <location filename="../src/util_msaedit/MsaUtilTasks.cpp" line="59"/>
        <source>Translate nucleic alignment to amino</source>
        <translation>Трансляция нуклеотидного выравнивания в амино</translation>
    </message>
    <message>
        <location filename="../src/util_msaedit/MsaUtilTasks.cpp" line="53"/>
        <source>Unable to find suitable translation for %1</source>
        <translation>Невозможно найти подходящую трансляцию для %1</translation>
    </message>
</context>
</TS>
